<?php namespace Concrete\Package\EnlilStackLink\Block\EnlilStackLink;

use Concrete\Core\Page\Page;
use Concrete\Core\Block\BlockController;
use Concrete\Core\User\User;
use Concrete\Core\Permission\Checker as Permissions;


class Controller extends BlockController {
	
	protected $btInterfaceWidth = 500;
	protected $btInterfaceHeight = 350;
	protected $btTable = 'btEnlilStackLink';
	protected $btWrapperClass = 'ccm-ui';
	protected $btDefaultSet = 'enlil_stacks';
	
	protected $btCacheBlockRecord = false;
	protected $btCacheBlockOutput = false;
	protected $btCacheBlockOutputOnPost = false;
	protected $btCacheBlockOutputForRegisteredUsers = false;
	
	public function getBlockTypeName() {
		return t("Enlil Stack Link");
	}
	
	public function getBlockTypeDescription() {
		return t("Quick Links to Edit Stacks");
	}
	
	
	public function validate($args) {
		
		$e = $this->app->make('error');
		$page = Page::getCurrentPage();
		$stack = $this->isStack($page);
		
		// Restrict adding block to Areas & Global Areas on a Page
		if (!$stack) {
			
			$e->add(t('Stack Link Block MUST be placed in Stacks ONLY'));
		}
		
		// Restrict adding block to Global Areas in Dashboard
		if ($stack && $this->isStackGlobal($stack)) {
			
			$e->add(t('Stack Link Block MUST be placed in Stacks ONLY'));
		}
		
		return $e;
	}
	
	
	function save($args) {
		
		$args['slTarget'] = ($args['slTarget']) ? $args['slTarget'] : 0;
		
		//Auto Center block style buttons
		if (strpos($args['slBsClass'], 'block_') !== false) {
			
			$args['slBsAlign'] = 'center';
		}
		
		parent::save($args);
	}
	
	
	public function on_page_view() {
		
		// Hide copy to clipboard block menu option in edit mode
		$page = Page::getCurrentPage();
		$c = Page::getByID($this->getBlockCollectionID());
		
		if (is_object($page) && $page->isEditMode()) {
			
			$stack = $this->isStack($c);
			
			if ($stack || $this->isStackGlobal($stack)) { // or if the block happens to be in global area
				
				$style = '<style>#ccm-popover-menu-container > div[data-block-menu="block-menu-b' . $this->bID . '"] > div.popover-inner > ul.dropdown-menu > li > a[data-menu-action="block_scrapbook"] { display: none!important; }</style>';
				$this->addHeaderItem($style);
			}
		}
	}
	
	
	// Get Content //
	public function getContent() {
		
		$content = '';
		$c = Page::getByID($this->getBlockCollectionID());
		$stack = $this->isStack($c);
		
		if ($stack && !$this->isStackGlobal($stack)) {
			
			$cPermissions = new Permissions($c);
			if ($cPermissions->canEditPageContents()) { // Current User Can edit 'Contents'.  *Contents/Properties*
				
				$classParts = Array($this->getClass(), $this->getSize());
				$class = implode(' ', $classParts);
				
				$content = '<div class="' . $this->getAlign() . '"><a class="' . $class . '" href="' . $c->getCollectionLink() . '">' . t('Edit Stack: ') . $c->getCollectionName() . '</a></div>';
				if ($this->slTarget) {
					
					$content = '<div class="' . $this->getAlign() . '"><a class="' . $class . '" target="_blank" href="' . $c->getCollectionLink() . '">' . t('Edit Stack: ') . $c->getCollectionName() . '</a></div>';
				}
			}
		}
		
		return $content;
	}
	// Get Content END //

	
	public function getBlockCollectionID() {
	
		$blockCollectionID = Page::getCurrentPage()->getCollectionID();
		if ( is_object($this->block->getBlockCollectionObject()) ) {
			
			$blockCollectionID = $this->block->getBlockCollectionObject()->getCollectionID();
		}
		
		elseif ($this->block->isAlias()) {
			
			$blockCollectionID = $this->block->getBlockCollectionID();
		}
		
		return $blockCollectionID;
	}
	
	
	public function isStack($cObj = null) { // Return Stack Object (true) or false
		
		$isStack = false;
		if ($cObj instanceof \Concrete\Core\Page\Page) {
			
			//May return null if not a stack, rendering our next test useless.  Must test this at some point.  @mnakalay
			$cStack = \Concrete\Core\Page\Stack\Stack::getByID($cObj->getCollectionID());
			if ($cStack instanceof \Concrete\Core\Page\Stack\Stack) { //$stack->getPageTypeHandle() == STACKS_PAGE_TYPE;
				
				$isStack = $cStack;
			}
		}
		
		return $isStack;
	}
	
	
	public function isStackGlobal($sObj = null) {
		
		$isStackGlobal = false;
		if ($sObj instanceof \Concrete\Core\Page\Stack\Stack) {
			
			if ($sObj->getStackType() == \Concrete\Core\Page\Stack\Stack::ST_TYPE_GLOBAL_AREA) { // stackTypes 0 => Area | 20 => Global Area
				
				$isStackGlobal = true;
			}
		}
		
		return $isStackGlobal;
	}
	
	
	public function getEditModeWrap() {
		
		$c = Page::getByID($this->getBlockCollectionID());
				
		// Block is on a Page or in a Global Area or in a clipboard block which we dont want and *shouldnt* happen
		$message = '<b><span class="text-danger">' . t('Block Not In Stack') . '</span></b><br>';
		$message = $message . '<b><small>' . t('No Output To Display') . '</small></b>';
		
		$stack = $this->isStack($c);
		
		if ($stack && !$this->isStackGlobal($stack)) {
			
			// Block is in a Stack
			$message = '<b><span class="text-success">' . t('Block In Stack') . '</span></b><br>';
		}
		
		$editModeWrapOpen = '<div class="ccm-edit-mode-disabled-item">';
		$editModeWrapOpen = $editModeWrapOpen . '<b>' . t('Enlil Stack Link') . '</b><br>';
		$editModeWrapOpen = $editModeWrapOpen . '<div class="clearfix" style="border-bottom: 1px solid #d0d0d0; margin-bottom: 4px;"></div>';
		$editModeWrapOpen = $editModeWrapOpen . $message;
		
		$editModeWrap = Array('open' => $editModeWrapOpen, 'close' => '</div>');
		
		return $editModeWrap;
	}
	
	
	public function getClass() {
	
		switch ($this->slBsClass) {
			
			case 'button_link':
				$class = 'btn btn-link'; break;
			case 'button_default':
				$class = 'btn btn-default'; break;
			case 'button_primary':
				$class = 'btn btn-primary'; break;
			case 'button_success':
				$class = 'btn btn-success'; break;
			case 'button_info':
				$class = 'btn btn-info'; break;
			case 'button_warning':
				$class = 'btn btn-warning'; break;
			case 'button_danger':
				$class = 'btn btn-danger'; break;
			
			
			case 'block_link':
				$class = 'btn btn-block btn-link'; break;
			case 'block_hover':
				$class = 'btn btn-block text-primary'; break;
			case 'block_default':
				$class = 'btn btn-block btn-default'; break;
			case 'block_primary':
				$class = 'btn btn-block btn-primary'; break;
			case 'block_success':
				$class = 'btn btn-block btn-success'; break;
			case 'block_info':
				$class = 'btn btn-block btn-info'; break;
			case 'block_warning':
				$class = 'btn btn-block btn-warning'; break;
			case 'block_danger':
				$class = 'btn btn-block btn-danger'; break;
			
			
			case 'block_alert-success':
				$class = 'btn btn-block alert-success text-success'; break;
			case 'block_alert-success_hover':
				$class = 'btn btn-block alert-success text-success bg-success'; break;
			case 'block_alert-info':
				$class = 'btn btn-block alert-info text-info'; break;
			case 'block_alert-info_hover':
				$class = 'btn btn-block alert-info text-info bg-info'; break;
			case 'block_alert-warning':
				$class = 'btn btn-block alert-warning text-warning'; break;
			case 'block_alert-warning_hover':
				$class = 'btn btn-block alert-warning text-warning bg-warning'; break;
			case 'block_alert-danger':
				$class = 'btn btn-block alert-danger text-danger'; break;
			case 'block_alert-danger_hover':
				$class = 'btn btn-block alert-danger text-danger bg-danger'; break;
			
			
			default:
				$class = 'btn btn-link'; break;
		}
		
		return $class;
	}
	
	
	public function getSize() {
	
		switch ($this->slBsSize) {
			
			case 'xs':
				$size = 'btn btn-xs'; break;
			case 'sm':
				$size = 'btn btn-sm'; break;
			case 'md':
				$size = ''; break;
			case 'lg':
				$size = 'btn btn-lg'; break;
			
			
			default:
				$size = 'btn btn-xs'; break;
		}
		
		return $size;
	}
	
	
	public function getAlign() {
	
		switch ($this->slBsAlign) {
			
			case 'left':
				$align = 'text-left'; break;
			case 'right':
				$align = 'text-right'; break;
			case 'center':
				$align = 'text-center'; break;
			
			
			default:
				$align = 'text-left'; break;
		}
		
		return $align;
	}
	
	
	
	
	
}
