<?php namespace Concrete\Package\EnlilStackLink;

use \Concrete\Core\Package\Package;
use \Concrete\Core\Block\BlockType\BlockType;
use \Concrete\Core\Block\BlockType\Set as BlockTypeSet;


class Controller extends Package {

    protected $pkgHandle = 'enlil_stack_link';
    protected $appVersionRequired = '8.5.2';
    protected $pkgVersion = '0.9.5.0';

    public function getPackageName() {
		return t("Enlil Stack Link");
    }

	public function getPackageDescription() {
		return t("Quick Links to Edit Stacks");
    }

    
	public function install() {
        $pkg = parent::install();
		$this->installPackage($pkg);
	}
	 
	public function upgrade() {
		$pkg = $this;
		parent::upgrade();
		$this->installPackage($pkg);
	}
	
	public function uninstall() {
		$this->cleanBlockTypeSets();
		parent::uninstall();
	}
	
	private function cleanBlockTypeSets() {
		$blockTypeSet = BlockTypeSet::getByHandle('enlil_stacks');
		$blockTypes = $blockTypeSet->getBlockTypes();
		$count = 0;
		foreach ($blockTypes as $blockType) {
			if ($blockType) {
				// Ignore known block types.  We clean before uninstall, so block types are still assigned.
				if ($blockType->getBlockTypeHandle() == 'enlil_stack_link') { continue; }
				$count++;
			}
			if ($count == 1) { break; } // Another block type needs the BlockTypeSet, bail out of loop.
		}
		// Clear, then delete set if otherwise empty.
		if ($count == 0) { $blockTypeSet->clearBlockTypes(); $blockTypeSet->delete(); }
	}
	
	
	
	private function installPackage($pkg) {
		$this->installBlockTypeSets($pkg);
		$this->installBlocks($pkg);
	}
	
	private function installBlockTypeSets($pkg) {
		if (!BlockTypeSet::getByHandle('enlil_stacks')) {
			BlockTypeSet::add('enlil_stacks', 'Enlil Stacks');
		}
	}
	
	private function installBlocks($pkg) {
		$bt = BlockType::getByHandle('enlil_stack_link');
		if (!$bt || !is_object($bt)){
			BlockType::installBlockType('enlil_stack_link', $pkg);
		}
	}
	
	
	
	
}
